function snr = CalcSNRMul(mImage1, mImage2)
% CalcPSNR returns the PSNR between the original image and its approximation
%
% Calculates the Peak Signal to Noise Ratio (PSNR) between 2 matrices containing
% pixel intensity values.
%
% Usage:            psnr = CalcPSNR( mImage1, mImage2 );
%
% Inputs:
%   mImage1         matrix of pixel intensity values representing the original image
%   mImage2         matrix of pixel intensity values representing the approximated image
%   maxIntensity    maximum allowed pixel intensity, defualt is 256 (8 bit image) 
%
% Outputs:
%    psnr       the PSNR resulting from the  approximation
%

error(nargchk(2,3,nargin));

mImage1=mImage1';
mImage2=mImage2';

%[ y, x ] = size(mImage1);
mse=(norm(mImage1(1,:)-mImage2(1,:))^2+norm(mImage1(2,:)-mImage2(2,:))^2);
nor=norm(mImage1(1,:))^2+norm(mImage1(2,:))^2;
%mse=mse/( x*y );
snr = 10*log10((nor)/mse);
